@@ -18,7 +18,7 @@ The 'call' method will be in charge of looking for the right function and callin
 """
 
 
-def add_edge(g, ctx, ref1, ref2, **data):
-    node1 = ctx[ref1]
-    node2 = ctx[ref2]
-    g.add_edge(node1, node2, **data)
+def add_edge(_g, _ctx, _ref1, _ref2, **data):
+    node1 = _ctx[_ref1]
+    node2 = _ctx[_ref2]
+    _g.add_edge(node1, node2, **data)
